{% extends requisition_listboard_template %}

{% block panel_action_buttons %}
       <button class="btn btn-sm btn-default" type="submit" id="action" name="action" form="{{ form_action_name }}" value="process">Process</button>
{% endblock panel_action_buttons %}
