# Generated by Django 5.0 on 2023-12-08 00:49

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_data_manager", "0035_datadictionary_edc_data_ma_model_92b469_idx"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalqueryrule",
            name="rule_handler_name",
            field=models.CharField(
                choices="(('do_nothing', 'Do Nothing'), ('default', 'Default'))",
                default="default",
                max_length=150,
            ),
        ),
        migrations.AlterField(
            model_name="queryrule",
            name="rule_handler_name",
            field=models.CharField(
                choices="(('do_nothing', 'Do Nothing'), ('default', 'Default'))",
                default="default",
                max_length=150,
            ),
        ),
    ]
