{% extends "admin/base_site.html" %}
{% load i18n admin_urls static edc_admin_modify %}

{% block extrahead %}{{ block.super }}
    <script src="{% static 'fontawesomefree/js/all.min.js' %}"></script>
{% endblock %}

{% block extrastyle %}{{ block.super }}
<link rel="stylesheet" href="{% static "admin/css/dashboard.css" %}">
{%  for css in edc_model_admin_css_theme_path %}
<link rel='stylesheet' type="text/css" href='{% static css %}'>
{% endfor %}
{% endblock %}

{% block dark-mode-vars %}
<link rel="stylesheet" type="text/css" href="{% static 'edc_model_admin/css/dark_mode.css' %}">
{% endblock %}

{% block coltype %}colMS{% endblock %}

{% block bodyclass %}{{ block.super }} dashboard{% endblock %}

{% block breadcrumbs %}{% endblock %}


{% block content %}
<div id="content-main">
  {% include "admin/app_list.html" with app_list=app_list show_changelinks=True %}
</div>
{% endblock %}


{% block sidebar %}
<div id="content-related">
    <div class="module" id="recent-actions-module">
        <h2>{% translate 'Recent actions' %}</h2>
        <h3>{% translate 'My actions' %}</h3>
            {% load log %}
            {% get_admin_log 10 as admin_log for_user user %}
            {% if not admin_log %}
            <p>{% translate 'None available' %}</p>
            {% else %}
            <ul class="actionlist">
            {% for entry in admin_log %}
            <li class="{% if entry.is_addition %}addlink{% endif %}{% if entry.is_change %}changelink{% endif %}{% if entry.is_deletion %}deletelink{% endif %}">
                {% if entry.is_deletion or not entry.get_admin_url %}
                    {{ entry.object_repr }}
                {% else %}
                    <a href="{{ entry.get_admin_url }}">{{ entry.object_repr }}</a>
                {% endif %}
                <br>
                {% if entry.content_type %}
                    <span class="mini quiet">{% filter capfirst %}{{ entry.content_type.name }}{% endfilter %}</span>
                {% else %}
                    <span class="mini quiet">{% translate 'Unknown content' %}</span>
                {% endif %}
            </li>
            {% endfor %}
            </ul>
            {% endif %}
    </div>
</div>
{% endblock %}

{#{% block branding %}#}
{#  <button type="button" class="btn btn-{% if LIVE_SYSTEM and not DEBUG %}live{% else %}test{% endif %}">#}
{#    {% if LIVE_SYSTEM and not DEBUG %}{{ LIVE|title }}{% else %}{{ TEST|title }}{% endif %}#}
{#  </button>&nbsp;#}
{#  {{ protocol_name |default:project_name }}: {{ request.site.name|title }} ({{ request.site.id }}) &nbsp;#}
{#  <a href="/">{% translate 'Home' %}</a> &rsaquo;#}
{#    {% if site_url %}#}
{#        <a href="{{ site_url }}">{% translate 'Administration' %}</a>#}
{#    {% endif %} &nbsp;&nbsp;&nbsp;#}
{#{% endblock %}#}

{% block branding %}
  {% show_navbar_for_admin_templates_b3 %}
{% endblock %}

{% block welcome-msg %}{% endblock %}

{% block userlinks %}{% logout_row %}{% endblock %}
