# Generated by Django 2.1 on 2018-10-18 23:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [("edc_notification", "0002_update_notifications")]

    # this is now run as in post migrate
    # operations = [migrations.RunPython(site_notifications.update_notification_list)]

    operations = []
