# Generated by Django 2.2.2 on 2019-09-22 02:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_visit_schedule", "0006_auto_20190706_0706")]

    operations = [
        migrations.AlterField(
            model_name="subjectschedulehistory",
            name="subject_identifier",
            field=models.CharField(max_length=50),
        )
    ]
