<a id="{{ btn.btn_id }}" role="button" class="btn btn-sm btn-{{ btn.color|default:"default" }}"
   {{ btn.disabled }} {% if not btn.disabled %}href="{{ btn.url }}" data-toggle="tooltip" title="{{ btn.title }}"{% endif %}>
    <i class="fas {{ btn.fa_icon|default:"fa-pencil-alt" }} fa-fw" aria-hidden="true"></i> {{ btn.label }}
</a>
