BLOOD_GLUCOSE = "blood_glucose"
BLOOD_GLUCOSE_POC = "blood_glucose_poc"
CD4 = "CD4"
CHEMISTRY_LFT = "chemistry_lft"
CHEMISTRY_LIPIDS = "chemistry_lipids"
CHEMISTRY_RFT = "chemistry_rft"
CHOL = "chol"
FBC = "fbc"
HAEMOGLOBIN = "haemoglobin"
HBA1C = "hba1c"
HBA1C_POC = "hba1c_poc"
HCT = "hct"
HDL = "hdl"
INSULIN = "insulin"
LDL = "ldl"
LFT = "LFT"
LIPIDS = "LIPIDS"
LYMPHOCYTE = "lymphocyte"
LYMPHOCYTE_DIFF = "lymphocyte_diff"
MCH = "mch"
MCHC = "mchc"
MCV = "mcv"
NEUTROPHIL = "neutrophil"
NEUTROPHIL_DIFF = "neutrophil_diff"
PLATELETS = "platelets"
RBC = "rbc"
RFT = "RFT"
SPUTUM = "sputum"
TRIG = "trig"
VL = "viral_load"
WBC = "wbc"
