# Generated by Django 4.2.10 on 2024-03-07 15:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_data_manager",
            "0037_alter_dataquery_site_alter_historicaldataquery_site_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="datadictionary",
            old_name="default",
            new_name="default_value",
        ),
        migrations.RenameField(
            model_name="historicaldatadictionary",
            old_name="default",
            new_name="default_value",
        ),
    ]
