# Generated by Django 2.2.6 on 2019-10-24 01:26

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [("edc_randomization", "0002_historicalrandomizationlist")]

    operations = [
        migrations.AlterModelOptions(
            name="randomizationlist",
            options={
                "ordering": ("site_name", "sid"),
                "permissions": (("display_assignment", "Can display assignment"),),
            },
        )
    ]
