# Generated by Django 4.2.9 on 2024-01-30 01:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_auth", "0031_alter_edcpermissions_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="userprofile",
            name="is_multisite_viewer",
            field=models.BooleanField(default=False),
        ),
    ]
