{% extends "edc_model_admin/admin/change_list.html" %}
{% load i18n admin_urls static admin_list edc_admin_modify %}

{% block branding %}
  {% show_navbar_for_admin_templates_b3 %}&nbsp;<a href="{% url "edc_adverse_event:home_url" %}">{{ opts.app_config.verbose_name|capfirst }}</A>&nbsp;&rsaquo;&nbsp;{{ opts.verbose_name|capfirst }}
{% endblock %}
