# Generated by Django 5.1.2 on 2024-11-18 15:45

from django.db import migrations, models

import edc_pharmacy.models.stock.managers


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0042_remove_historicaldispensinghistory_history_user_and_more",
        ),
    ]

    operations = [
        migrations.CreateModel(
            name="StockProxy",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("edc_pharmacy.stock",),
            managers=[
                ("objects", edc_pharmacy.models.stock.managers.StockManager()),
            ],
        ),
        migrations.AlterField(
            model_name="historicallot",
            name="lot_no",
            field=models.CharField(db_index=True, max_length=50, verbose_name="Batch"),
        ),
        migrations.AlterField(
            model_name="lot",
            name="lot_no",
            field=models.CharField(max_length=50, unique=True, verbose_name="Batch"),
        ),
    ]
