# Generated by Django 2.2.6 on 2019-11-01 21:33

from django.db import migrations

import edc_model_fields.fields.other_charfield


class Migration(migrations.Migration):
    dependencies = [("edc_offstudy", "0007_auto_20191024_1000")]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectoffstudy",
            name="offstudy_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="subjectoffstudy",
            name="offstudy_reason_other",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
