# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-11 10:05
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [("edc_metadata", "0002_auto_20161127_2226")]

    operations = [
        migrations.AlterModelOptions(
            name="crfmetadata",
            options={
                "ordering": ("show_order",),
                "verbose_name": "Crf Metadata",
                "verbose_name_plural": "Crf Metadata",
            },
        ),
        migrations.AlterModelOptions(
            name="requisitionmetadata",
            options={
                "ordering": ("show_order",),
                "verbose_name": "Requisition Metadata",
                "verbose_name_plural": "Requisition Metadata",
            },
        ),
    ]
