{% load i18n %}
<H5>
  <B><span style="color: orange">{%  trans "Interviewer to read"  %}</span></B>
</H5>
<p>
  {%  trans "People may miss taking their medicines for various reasons. What was the reason you missed taking your pills the last time?" %}
</p>
