# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.db.models.deletion
import django.utils.timezone
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_data_manager", "0040_alter_datadictionary_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dataquery",
            name="dm_user",
            field=models.ForeignKey(
                blank=True,
                help_text="Please select a name from the list",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_data_manager.datamanageruser",
                verbose_name="DM resolved by",
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="locked_reason",
            field=models.TextField(
                blank=True,
                default="",
                help_text="If required, the reason the query cannot be resolved.",
                verbose_name="Reason query locked",
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="plan_of_action",
            field=models.TextField(
                blank=True,
                default="",
                help_text="If required, provide a plan of action",
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Query date"
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="rule_reference",
            field=models.CharField(
                default=uuid.uuid4, max_length=150, verbose_name="Query rule reference"
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="sender",
            field=models.ForeignKey(
                help_text="Please select a name from the list",
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_data_manager.datamanageruser",
                verbose_name="Query raised by",
            ),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="site_response_text",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="subject_identifier",
            field=models.CharField(default="", editable=False, max_length=50),
        ),
        migrations.AlterField(
            model_name="dataquery",
            name="title",
            field=models.CharField(default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="dm_user",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Please select a name from the list",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_data_manager.datamanageruser",
                verbose_name="DM resolved by",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="locked_reason",
            field=models.TextField(
                blank=True,
                default="",
                help_text="If required, the reason the query cannot be resolved.",
                verbose_name="Reason query locked",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="plan_of_action",
            field=models.TextField(
                blank=True,
                default="",
                help_text="If required, provide a plan of action",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Query date"
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="rule_reference",
            field=models.CharField(
                default=uuid.uuid4, max_length=150, verbose_name="Query rule reference"
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="sender",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                help_text="Please select a name from the list",
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_data_manager.datamanageruser",
                verbose_name="Query raised by",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="site_response_text",
            field=models.TextField(blank=True, default=""),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="subject_identifier",
            field=models.CharField(default="", editable=False, max_length=50),
        ),
        migrations.AlterField(
            model_name="historicaldataquery",
            name="title",
            field=models.CharField(default="", max_length=150),
        ),
    ]
