# Generated by Django 3.2.13 on 2022-09-18 02:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_offstudy", "0013_alter_historicalsubjectoffstudy_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectoffstudy",
            name="consent_model",
            field=models.CharField(editable=False, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalsubjectoffstudy",
            name="consent_version",
            field=models.CharField(editable=False, max_length=10, null=True),
        ),
        migrations.AddField(
            model_name="subjectoffstudy",
            name="consent_model",
            field=models.CharField(editable=False, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="subjectoffstudy",
            name="consent_version",
            field=models.CharField(editable=False, max_length=10, null=True),
        ),
    ]
