# Generated by Django 4.0.7 on 2022-08-23 13:24

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_locator", "0025_auto_20220704_1841"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectlocator",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name="subjectlocator",
            name="action_identifier",
            field=models.CharField(blank=True, max_length=50, unique=True),
        ),
    ]
