# Generated by Django 6.0 on 2025-03-13 11:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0063_alter_allocation_managers_remove_allocation_site_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstockrequest",
            name="start_datetime",
            field=models.DateTimeField(
                blank=True,
                default=None,
                help_text="If provided, will not include appointments before this date. May be left blank",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="stockrequest",
            name="start_datetime",
            field=models.DateTimeField(
                blank=True,
                default=None,
                help_text="If provided, will not include appointments before this date. May be left blank",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalstockrequest",
            name="cutoff_datetime",
            field=models.DateTimeField(
                blank=True,
                default=None,
                help_text="If provided, will not include appointments after this date. May be left blank",
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="stockrequest",
            name="cutoff_datetime",
            field=models.DateTimeField(
                blank=True,
                default=None,
                help_text="If provided, will not include appointments after this date. May be left blank",
                null=True,
            ),
        ),
    ]
