# -*- coding: utf-8 -*-
# Generated by Django 1.10.3 on 2016-12-21 21:35
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_appointment", "0004_auto_20161210_1408")]

    operations = [
        migrations.AlterField(
            model_name="appointment",
            name="subject_identifier",
            field=models.CharField(max_length=50, verbose_name="Subject Identifier"),
        ),
        migrations.AlterField(
            model_name="historicalappointment",
            name="subject_identifier",
            field=models.CharField(max_length=50, verbose_name="Subject Identifier"),
        ),
    ]
