# Generated by Django 5.1.2 on 2024-11-18 02:17

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0040_historicalstock_dispensed_stock_dispensed"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dispenseitem",
            name="dispense",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.dispense",
                verbose_name="Dispense",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldispenseitem",
            name="dispense",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_pharmacy.dispense",
                verbose_name="Dispense",
            ),
        ),
    ]
