# Generated by Django 4.2.11 on 2024-06-17 22:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_qareports", "0002_rename_reportnote_qareportnote_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="qareportnote",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "QA Report Note",
                "verbose_name_plural": "QA Report Notes",
            },
        ),
        migrations.RemoveConstraint(
            model_name="qareportnote",
            name="edc_qareports_qareportnote_name_subj_uniq",
        ),
        migrations.AddConstraint(
            model_name="qareportnote",
            constraint=models.UniqueConstraint(
                fields=("report_model", "subject_identifier"),
                name="edc_qareports_qareportnote_report_model_subj_uniq",
            ),
        ),
    ]
