# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-21 23:23
from __future__ import unicode_literals
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_identifier", "0008_identifiermodel_linked_identifier")]

    operations = [
        migrations.AlterField(
            model_name="historicalidentifierhistory",
            name="created_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="identifierhistory",
            name="created_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
