# Generated by Django 2.0.1 on 2018-01-16 12:11

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [("edc_identifier", "0015_auto_20180116_1235")]

    operations = [
        migrations.AlterField(
            model_name="identifiermodel",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="sites.Site",
            ),
        )
    ]
