# Generated by Django 5.1.2 on 2024-11-15 14:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0027_rename_at_location_historicalstock_transferred_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalstock",
            name="transferred",
        ),
        migrations.RemoveField(
            model_name="stock",
            name="transferred",
        ),
    ]
