# Generated by Django 5.2.3 on 2025-06-26 22:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0069_alter_historicalstoragebin_capacity_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="stockout",
            name="codes",
            field=models.CharField(max_length=150, null=True),
        ),
    ]
