# Generated by Django 5.2.3 on 2025-07-09 20:40

from django.db import migrations

import edc_pharmacy.models.stock.confirmation


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0081_historicalconfirmation_confirmation"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="confirmation",
            managers=[
                ("objects", edc_pharmacy.models.stock.confirmation.Manager()),
            ],
        ),
        migrations.RemoveField(
            model_name="confirmation",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicalconfirmation",
            name="site",
        ),
    ]
