# Generated by Django 5.1.2 on 2024-11-19 11:42

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0045_historicallot_manufacture_date_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalrx",
            name="slug",
        ),
        migrations.RemoveField(
            model_name="rx",
            name="slug",
        ),
    ]
