# Generated by Django 5.2.6 on 2025-09-17 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_registration",
            "0032_alter_historicalregisteredsubject_revision_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="additional_key",
            field=models.CharField(
                default="",
                editable=False,
                help_text="A uuid (or some other text value) to be added to bypass the unique constraint of just firstname, initials, and dob.The default constraint proves limiting since the source model usually has some other attribute in additional to first_name, initials and dob which is not captured in this model",
                max_length=36,
                verbose_name="-",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="comment",
            field=models.TextField(
                blank=True, default="", max_length=250, verbose_name="Comment"
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="dm_comment",
            field=models.CharField(
                default="",
                editable=False,
                max_length=150,
                verbose_name="Data Management comment",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="ethnicity",
            field=models.CharField(blank=True, default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female")],
                default="",
                max_length=1,
                verbose_name="Gender",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="randomization_list_model",
            field=models.CharField(default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="registration_identifier",
            field=models.CharField(blank=True, default="", max_length=36),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="registration_status",
            field=models.CharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name="Registration status",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="relative_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="For example, mother's identifier, if available / appropriate",
                max_length=36,
                verbose_name="Identifier of immediate relation",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="screening_identifier",
            field=models.CharField(blank=True, default="", max_length=36),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="sid",
            field=models.CharField(
                blank=True, default="", max_length=15, verbose_name="SID"
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="subject_consent_id",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalregisteredsubject",
            name="subject_type",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="additional_key",
            field=models.CharField(
                default="",
                editable=False,
                help_text="A uuid (or some other text value) to be added to bypass the unique constraint of just firstname, initials, and dob.The default constraint proves limiting since the source model usually has some other attribute in additional to first_name, initials and dob which is not captured in this model",
                max_length=36,
                verbose_name="-",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="comment",
            field=models.TextField(
                blank=True, default="", max_length=250, verbose_name="Comment"
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="dm_comment",
            field=models.CharField(
                default="",
                editable=False,
                max_length=150,
                verbose_name="Data Management comment",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="ethnicity",
            field=models.CharField(blank=True, default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="gender",
            field=models.CharField(
                choices=[("M", "Male"), ("F", "Female")],
                default="",
                max_length=1,
                verbose_name="Gender",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="randomization_list_model",
            field=models.CharField(default="", max_length=150),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="registration_identifier",
            field=models.CharField(blank=True, default="", max_length=36),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="registration_status",
            field=models.CharField(
                blank=True,
                default="",
                max_length=25,
                verbose_name="Registration status",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="relative_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="For example, mother's identifier, if available / appropriate",
                max_length=36,
                verbose_name="Identifier of immediate relation",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="screening_identifier",
            field=models.CharField(blank=True, default="", max_length=36),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="sid",
            field=models.CharField(
                blank=True, default="", max_length=15, verbose_name="SID"
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="subject_consent_id",
            field=models.CharField(blank=True, default="", max_length=100),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="registeredsubject",
            name="subject_type",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
    ]
