# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0089_alter_allocation_allocated_by_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="allocation",
            name="allocation_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="confirmation",
            name="confirmed_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="confirmationatsite",
            name="transfer_confirmation_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="confirmationatsiteitem",
            name="transfer_confirmation_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="dispense",
            name="dispense_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="dispenseitem",
            name="dispense_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalallocation",
            name="allocation_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalconfirmation",
            name="confirmed_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalconfirmationatsite",
            name="transfer_confirmation_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalconfirmationatsiteitem",
            name="transfer_confirmation_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicaldispense",
            name="dispense_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicaldispenseitem",
            name="dispense_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalreceive",
            name="receive_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalreceiveitem",
            name="receive_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalrepackrequest",
            name="repack_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="rx_date",
            field=models.DateField(
                default=django.utils.timezone.now, verbose_name="Date RX written"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstock",
            name="stock_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, help_text="date stock record created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalstockadjustment",
            name="adjustment_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstockrequest",
            name="request_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstockrequestitem",
            name="request_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstocktransfer",
            name="transfer_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstocktransferitem",
            name="transfer_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstoragebin",
            name="bin_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalstoragebinitem",
            name="item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalsupplier",
            name="supplier_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="receive",
            name="receive_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="receiveitem",
            name="receive_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="repackrequest",
            name="repack_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="rx",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="rx",
            name="rx_date",
            field=models.DateField(
                default=django.utils.timezone.now, verbose_name="Date RX written"
            ),
        ),
        migrations.AlterField(
            model_name="stock",
            name="stock_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, help_text="date stock record created"
            ),
        ),
        migrations.AlterField(
            model_name="stockadjustment",
            name="adjustment_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="stockavailability",
            name="created",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="stockrequest",
            name="request_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="stockrequestitem",
            name="request_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="stocktransfer",
            name="transfer_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="stocktransferitem",
            name="transfer_item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="storagebin",
            name="bin_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="storagebinitem",
            name="item_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="supplier",
            name="supplier_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
