# Generated by Django 5.1.2 on 2024-11-27 16:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "edc_pharmacy",
            "0053_alter_location_managers_alter_historicalstock_lot_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalreceiveitem",
            name="task_id",
            field=models.UUIDField(null=True),
        ),
        migrations.AddField(
            model_name="receiveitem",
            name="task_id",
            field=models.UUIDField(null=True),
        ),
    ]
