# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_refusal", "0012_alter_historicalsubjectrefusal_comment_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Report Date and Time"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now, verbose_name="Report Date and Time"
            ),
        ),
    ]
