# Generated by Django 5.2.6 on 2025-09-18 00:24

import django.utils.timezone
import edc_model.validators.date
import edc_protocol.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_visit_tracking", "0009_alter_historicalsubjectvisit_comments_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectvisit",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of this report",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="Date and time of this report",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report date and time",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="report_datetime",
            field=models.DateTimeField(
                default=django.utils.timezone.now,
                help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date",
            ),
        ),
    ]
