# Generated by Django 4.2.1 on 2023-07-07 19:25

from django.db import migrations

import edc_action_item.models.action_item


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_action_item",
            "0032_alter_actionitem_options_alter_actiontype_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="actionitem",
            managers=[
                ("objects", edc_action_item.models.action_item.ActionItemManager()),
                ("on_site", edc_action_item.models.action_item.CurrentSiteManager()),
            ],
        ),
    ]
