# Generated by Django 4.2.7 on 2023-11-28 02:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_metadata",
            "0024_rename_current_entry_title_crfmetadata_model_verbose_name_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="crfmetadata",
            name="document_user",
            field=models.CharField(max_length=50, null=True, verbose_name="User"),
        ),
        migrations.AddField(
            model_name="requisitionmetadata",
            name="document_user",
            field=models.CharField(max_length=50, null=True, verbose_name="User"),
        ),
        migrations.AlterField(
            model_name="crfmetadata",
            name="model_verbose_name",
            field=models.CharField(max_length=250, null=True, verbose_name="Document"),
        ),
        migrations.AlterField(
            model_name="requisitionmetadata",
            name="model_verbose_name",
            field=models.CharField(max_length=250, null=True, verbose_name="Document"),
        ),
    ]
