# Generated by Django 5.2.3 on 2025-07-04 13:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0078_alter_historicalstock_qty_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicalstock",
            name="allocated",
        ),
        migrations.RemoveField(
            model_name="stock",
            name="allocated",
        ),
    ]
