# Generated by Django 4.2.7 on 2023-12-04 22:36

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_adherence", "0003_nonadherencereasons_extra_value"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="nonadherencereasons",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Non-Adherence Reasons",
                "verbose_name_plural": "Non-Adherence Reasons",
            },
        ),
        migrations.RemoveIndex(
            model_name="nonadherencereasons",
            name="edc_adheren_id_0617c0_idx",
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_index",
            field=models.IntegerField(
                default=0,
                help_text="Index to control display order if not alphabetical, not required",
                verbose_name="display index",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="display_name",
            field=models.CharField(
                help_text="(suggest 40 characters max.)",
                max_length=250,
                unique=True,
                verbose_name="Name",
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="name",
            field=models.CharField(
                help_text="This is the stored value, required",
                max_length=250,
                unique=True,
                verbose_name="Stored value",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["display_index", "display_name"],
                name="edc_adheren_display_4c242c_idx",
            ),
        ),
    ]
