# Generated by Django 5.0.1 on 2024-02-12 22:37

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "edc_action_item",
            "0036_alter_actionitem_priority_alter_actionitem_site_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="actionitem",
            name="reference_model",
        ),
        migrations.RemoveField(
            model_name="actionitem",
            name="related_reference_model",
        ),
        migrations.RemoveField(
            model_name="historicalactionitem",
            name="reference_model",
        ),
        migrations.RemoveField(
            model_name="historicalactionitem",
            name="related_reference_model",
        ),
    ]
